aboutsummaryrefslogtreecommitdiffstats
path: root/params/protocol_params.go
diff options
context:
space:
mode:
Diffstat (limited to 'params/protocol_params.go')
-rw-r--r--params/protocol_params.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/params/protocol_params.go b/params/protocol_params.go
index 45a9a2549..2dfc251b6 100644
--- a/params/protocol_params.go
+++ b/params/protocol_params.go
@@ -40,8 +40,9 @@ var (
EcrecoverGas = big.NewInt(3000) //
Sha256WordGas = big.NewInt(12) //
- MinGasLimit = big.NewInt(5000) // Minimum the gas limit may ever be.
- GenesisGasLimit = big.NewInt(4712388) // Gas limit of the Genesis block.
+ MinGasLimit = big.NewInt(5000) // Minimum the gas limit may ever be.
+ GenesisGasLimit = big.NewInt(4712388) // Gas limit of the Genesis block.
+ TargetGasLimit = new(big.Int).Set(GenesisGasLimit) // The artificial target
Sha3Gas = big.NewInt(30) // Once per SHA3 operation.
Sha256Gas = big.NewInt(60) //